@@ -35,7 +35,6 @@ static GbWidget gbwidget;
 
 static gchar *Label = "CheckMenuItem|GtkItem::label";
 static gchar *State = "GtkCheckMenuItem::active";
-static gchar *Toggle = "GtkCheckMenuItem::always_show_toggle";
 
 
 /******
@@ -73,8 +72,6 @@ gb_check_menu_item_create_properties (GtkWidget * widget, GbWidgetCreateArgData
   property_add_text (Label, _("Label:"), _("The text to display"), 2);
   property_add_bool (State, _("Initially On:"),
 		     _("If the check menu item is initially on"));
-  property_add_bool (Toggle, _("Indicator:"),
-		     _("If the toggle indicator is always shown"));
 }
 
 
@@ -88,8 +85,7 @@ gb_check_menu_item_get_properties (GtkWidget * widget, GbWidgetGetArgData * data
 {
   gb_widget_output_child_label (widget, data, Label);
 
-  gb_widget_output_bool (data, State, data->widget_data->flags & GB_ACTIVE);
-  gb_widget_output_bool (data, Toggle, GTK_CHECK_MENU_ITEM (widget)->always_show_toggle);
+  gb_widget_output_bool (data, State, data->widget_data->flags & GLADE_ACTIVE);
 }
 
 
@@ -101,7 +97,7 @@ gb_check_menu_item_get_properties (GtkWidget * widget, GbWidgetGetArgData * data
 static void
 gb_check_menu_item_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 {
-  gboolean state, toggle;
+  gboolean state;
 
   gb_widget_input_child_label (widget, data, Label);
 
@@ -110,15 +106,10 @@ gb_check_menu_item_set_properties (GtkWidget * widget, GbWidgetSetArgData * data
     {
       gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (widget), state);
       if (state)
-	data->widget_data->flags |= GB_ACTIVE;
+	data->widget_data->flags |= GLADE_ACTIVE;
       else
-	data->widget_data->flags &= ~GB_ACTIVE;
+	data->widget_data->flags &= ~GLADE_ACTIVE;
     }
-
-  toggle = gb_widget_input_bool (data, Toggle);
-  if (data->apply)
-    gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (widget),
-					 toggle);
 }
 
 
@@ -133,7 +124,9 @@ gb_check_menu_item_create_popup_menu (GtkWidget * widget,
 				      GbWidgetCreateMenuData * data)
 {
   /* Add command to remove child label. */
+#if 0
   gb_widget_create_child_label_popup_menu (widget, data);
+#endif
 }
 
 
@@ -161,22 +154,10 @@ gb_check_menu_item_write_source (GtkWidget * widget, GbWidgetWriteSourceData *
   if (child && GTK_IS_LABEL (child) && !GB_IS_GB_WIDGET (child))
     {
       label_text = glade_util_get_label_text (child);
-      /* If there is an underlined accelerator, set up the accel signal. */
-      if (strchr (label_text, '_'))
-	{
-	  source_ensure_decl (data, "  guint tmp_key;\n");
-	  source_add (data,
-		      "  %s = gtk_check_menu_item_new_with_label (\"\");\n",
-		      data->wname);
-	  gb_menu_item_write_accel_source (widget, data, label_text);
-	}
-      else
-	{
-	  source_add (data,
-		      "  %s = gtk_check_menu_item_new_with_label (%s);\n",
-		      data->wname,
-		      source_make_string (label_text, data->use_gettext));
-	}
+      source_add (data,
+		  "  %s = gtk_check_menu_item_new_with_mnemonic (%s);\n",
+		  data->wname,
+		  source_make_string (label_text, data->use_gettext));
       g_free (label_text);
     }
   else
@@ -186,19 +167,12 @@ gb_check_menu_item_write_source (GtkWidget * widget, GbWidgetWriteSourceData *
 
   gb_widget_write_standard_source (widget, data);
 
-  if (data->widget_data->flags & GB_ACTIVE)
+  if (data->widget_data->flags & GLADE_ACTIVE)
     {
       source_add (data,
       "  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (%s), TRUE);\n",
 		  data->wname);
     }
-
-  if (GTK_CHECK_MENU_ITEM (widget)->always_show_toggle)
-    {
-      source_add (data,
-		  "  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (%s), TRUE);\n",
-		  data->wname);
-    }
 }
 
 
@@ -212,7 +186,8 @@ GbWidget *
 gb_check_menu_item_init ()
 {
   /* Initialise the GTK type */
-  gtk_check_menu_item_get_type ();
+  volatile GtkType type;
+  type = gtk_check_menu_item_get_type ();
 
   /* Initialize the GbWidget structure */
   gb_widget_init_struct (&gbwidget);
