@@ -157,7 +157,7 @@ gb_gnome_db_logindlg_write_source (GtkWidget * widget, GbWidgetWriteSourceData *
       gchar *title;
 
       title = GTK_WINDOW (widget)->title;
-      source_add (data, "  %s = gnome_db_logindlg_new (%s);\n",
+      source_add (data, "  %s = gnome_db_login_dialog_new (%s);\n",
 		  data->wname,
 		  title ? source_make_string (title, data->use_gettext)
 		        : "NULL");
@@ -202,6 +202,7 @@ gb_gnome_db_logindlg_init ()
   gbwidget.gb_widget_set_properties	= gb_gnome_db_logindlg_set_properties;
   gbwidget.gb_widget_write_source	= gb_gnome_db_logindlg_write_source;
   gbwidget.gb_widget_create_popup_menu	= gb_gnome_db_logindlg_create_popup_menu;
+  gbwidget.gb_widget_destroy = gb_window_destroy;
 
   return &gbwidget;
 }
